@@ -35,7 +35,7 @@
 #'
 #' @source
 #' \url{https://stat.ethz.ch/pipermail/r-help/2003-November/042126.html}
-#' \url{http://stackoverflow.com/questions/5302049/last-observation-carried-forward-na-locf-on-panel-cross-section-time-series}
+#' \url{https://stackoverflow.com/questions/5302049/last-observation-carried-forward-na-locf-on-panel-cross-section-time-series}
 #'
 #' This could probably be solved MUCH faster using Rcpp.
 #'
@@ -135,7 +135,7 @@ hc2axes <- function(x) {
     }
     x.axis[i] <- mean(x.tmp)
   }
-  return(data.frame(x.axis = x.axis, y.axis = y.axis))
+  return(data.frame(x.axis = x.axis, y.axis = y.axis, stringsAsFactors = TRUE))
 }
 
 
