@@ -8,7 +8,7 @@ knitr::opts_chunk$set(
   comment = "#>",
   tidy = FALSE)
 
-# http://stackoverflow.com/questions/24091735/why-pandoc-does-not-retrieve-the-image-file
+# https://stackoverflow.com/questions/24091735/why-pandoc-does-not-retrieve-the-image-file
 # < ! -- rmarkdown v1 -->
 
 
@@ -53,7 +53,7 @@ tanglegram(dendlist(dend1, dend2), margin_inner = 9,
 ## ---- echo=FALSE--------------------------------------------------------------
 
 c(person("Tal", "Galili", role = c("aut", "cre", "cph"), email =
-    "tal.galili@gmail.com", comment = "http://www.r-statistics.com"),
+    "tal.galili@gmail.com", comment = "https://www.r-statistics.com"),
     person("Gavin", "Simpson", role = "ctb"), person("Gregory","Jefferis", role
     = "ctb", email = "jefferis@gmail.com",
     comment ="imported code from his dendroextras package"),
@@ -495,7 +495,7 @@ heatmap.2(x, Rowv = Rowv, Colv = Colv)
 
 ## -----------------------------------------------------------------------------
 x  <- as.matrix(datasets::mtcars)
-# d3heatmap(x)
+# heatmaply(x)
 # now let's spice up the dendrograms a bit:
 Rowv  <- x %>% dist %>% hclust %>% as.dendrogram %>%
    set("branches_k_color", k = 3) %>% set("branches_lwd", 4) %>%
@@ -830,8 +830,6 @@ FM_index(cutree(hc1, k=3), cutree(hc2, k=3))
          
 # Using the R code:
 FM_index_R(cutree(hc1, k=3), cutree(hc2, k=3))
-# Or wrapping the code from profdpm: (notice the NA's)
-FM_index_profdpm(cutree(hc1, k=3), cutree(hc2, k=3))
 
 ## -----------------------------------------------------------------------------
 FM_index(cutree(hc1, k=3), cutree(hc2, k=3)) 
